==> sentry-6.1.0-beta.1.tar.gz: lib/src/transport/rate_limit_parser.dart <==
import 'rate_limit_category.dart';
import 'rate_limit.dart';

/// Parse rate limit categories and times from response header payloads.
class RateLimitParser {
  RateLimitParser(this._header);

  static const httpRetryAfterDefaultDelay = Duration(milliseconds: 60000);

  final String? _header;

  List<RateLimit> parseRateLimitHeader() {
    final rateLimitHeader = _header;
    if (rateLimitHeader == null) {
      return [];
    }
    final rateLimits = <RateLimit>[];
    final rateLimitValues = rateLimitHeader.toLowerCase().split(',');
    for (final rateLimitValue in rateLimitValues) {
      final durationAndCategories = rateLimitValue.trim().split(':');
      if (durationAndCategories.isEmpty) {
        continue;
      }
      final duration = _parseRetryAfterOrDefault(durationAndCategories[0]);
      if (durationAndCategories.length <= 1) {
        continue;
      }
      final allCategories = durationAndCategories[1];
      if (allCategories.isNotEmpty) {
        final categoryValues = allCategories.split(';');
        for (final categoryValue in categoryValues) {
          final category =
              RateLimitCategoryExtension.fromStringValue(categoryValue);
          if (category != RateLimitCategory.unknown) {
            rateLimits.add(RateLimit(category, duration));
          }
        }
      } else {
        rateLimits.add(RateLimit(RateLimitCategory.all, duration));
      }
    }
    return rateLimits;
  }

  List<RateLimit> parseRetryAfterHeader() {
    return [
      RateLimit(RateLimitCategory.all, _parseRetryAfterOrDefault(_header))
    ];
  }

  // Helper

  static Duration _parseRetryAfterOrDefault(String? value) {
    final durationInSeconds = int.tryParse(value ?? '');
    if (durationInSeconds != null) {
      return Duration(seconds: durationInSeconds);
    } else {
      return RateLimitParser.httpRetryAfterDefaultDelay;
    }
  }
}

==> sentry-8.0.0-beta.1.tar.gz: lib/src/transport/rate_limit_parser.dart <==
import 'data_category.dart';
import 'rate_limit.dart';

/// Parse rate limit categories and times from response header payloads.
class RateLimitParser {
  RateLimitParser(this._header);

  static const httpRetryAfterDefaultDelay = Duration(milliseconds: 60000);

  final String? _header;

  List<RateLimit> parseRateLimitHeader() {
    final rateLimitHeader = _header;
    if (rateLimitHeader == null) {
      return [];
    }
    final rateLimits = <RateLimit>[];
    final rateLimitValues = rateLimitHeader.toLowerCase().split(',');
    for (final rateLimitValue in rateLimitValues) {
      final durationAndCategories = rateLimitValue.trim().split(':');
      if (durationAndCategories.isEmpty) {
        continue;
      }
      final duration = _parseRetryAfterOrDefault(durationAndCategories[0]);
      if (durationAndCategories.length <= 1) {
        continue;
      }
      final allCategories = durationAndCategories[1];
      if (allCategories.isNotEmpty) {
        final categoryValues = allCategories.split(';');
        for (final categoryValue in categoryValues) {
          final category =
              _DataCategoryExtension._fromStringValue(categoryValue);
          if (category != DataCategory.unknown) {
            rateLimits.add(RateLimit(category, duration));
          }
        }
      } else {
        rateLimits.add(RateLimit(DataCategory.all, duration));
      }
    }
    return rateLimits;
  }

  List<RateLimit> parseRetryAfterHeader() {
    return [RateLimit(DataCategory.all, _parseRetryAfterOrDefault(_header))];
  }

  // Helper

  static Duration _parseRetryAfterOrDefault(String? value) {
    final durationInSeconds = int.tryParse(value ?? '');
    if (durationInSeconds != null) {
      return Duration(seconds: durationInSeconds);
    } else {
      return RateLimitParser.httpRetryAfterDefaultDelay;
    }
  }
}

extension _DataCategoryExtension on DataCategory {
  static DataCategory _fromStringValue(String stringValue) {
    switch (stringValue) {
      case '__all__':
        return DataCategory.all;
      case 'default':
        return DataCategory.dataCategoryDefault;
      case 'error':
        return DataCategory.error;
      case 'session':
        return DataCategory.session;
      case 'transaction':
        return DataCategory.transaction;
      case 'attachment':
        return DataCategory.attachment;
      case 'security':
        return DataCategory.security;
    }
    return DataCategory.unknown;
  }
}
